@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: api.cpp,v $
                              -------------------
-    cvs         : $Id: api.cpp,v 1.45 2003/07/03 00:05:00 aquamaniac Exp $
+    cvs         : $Id: api.cpp,v 1.47 2004/07/01 08:42:37 cstim Exp $
     begin       : Sat Jun 08 2002
     copyright   : (C) 2001 by Martin Preuss
     email       : openhbci@aquamaniac.de
@@ -932,7 +932,7 @@ Error API::registerMediumPlugin(Pointer<MediumPlugin> mp){
 
 string API::_getLibraryPrefix(const string &path) {
   string prefix;
-  unsigned int pp;
+  string::size_type pp;
 
   // get basename
   pp=path.rfind("/");
