@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: conf.cpp,v $
                              -------------------
-    cvs         : $Id: conf.cpp,v 1.5 2003/07/02 18:22:24 aquamaniac Exp $
+    cvs         : $Id: conf.cpp,v 1.7 2004/07/01 08:42:37 cstim Exp $
     begin       : Tue Dec 13 2001
     copyright   : (C) 2001 by Martin Preuss
     email       : martin@aquamaniac.de
@@ -362,7 +362,7 @@ Tree<ConfigNode>::iterator Config::createVar(string name,
                                                    Tree<ConfigNode>::iterator where){
   Error err;
   Tree<ConfigNode>::iterator tmpit;
-  unsigned int i;
+  string::size_type i;
   string prepath;
   string postpath;
 
@@ -416,7 +416,7 @@ Tree<ConfigNode>::iterator Config::createGroup(string name,
                                                      Tree<ConfigNode>::iterator where){
   Error err;
   Tree<ConfigNode>::iterator tmpit;
-  unsigned int i;
+  string::size_type i;
   string prepath;
   string postpath;
 
