@@ -440,7 +440,7 @@ string String::transformToHBCIBinData(const string &data) {
 
 
 string String::extractBinData(const string &data) {
-    unsigned int startOfBinaryData;
+    string::size_type startOfBinaryData;
 
     startOfBinaryData = data.find('@', 1) + 1;
     if (startOfBinaryData == string::npos)
