@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile: tree.h,v $
                              -------------------
-    cvs         : $Id: tree.h,v 1.5 2002/12/10 15:54:06 cstim Exp $
+    cvs         : $Id: tree.h,v 1.6 2004/06/24 21:40:24 cstim Exp $
     begin       : Sun Dec 09 2001
     copyright   : (C) 2001 by Martin Preuss
     email       : martin@aquamaniac.de
@@ -695,16 +695,16 @@ public:
    * Returns an iterator that points to the root of the tree.
    * @author Martin Preuss<martin@aquamaniac.de>
    */
-  Tree<T>::iterator root() {
-      return Tree<T>::iterator(&_root);
+  iterator root() {
+      return iterator(&_root);
   };
 
   /**
    * Returns an const_iterator that points to the root of the tree.
    * @author Martin Preuss<martin@aquamaniac.de>
    */
-  Tree<T>::const_iterator const_root() const {
-      return Tree<T>::const_iterator(&_root);
+  const_iterator const_root() const {
+      return const_iterator(&_root);
   };
 
   /**
